##################
MOLA documentation
##################

Welcome to **MOLA** (Modular Orchestration Library for Aerodynamics)
documentation website.

MOLA is an `ONERA <https://www.onera.fr>`_ code [#f1]_
that implements user-level workflows and tools for aerodynamic analysis. These
tools are essentially interfaces of multiple simulation techniques for computational fluid dynamics (CFD), 
with solvers `elsA <https://elsa.onera.fr>`_, `SoNICS <https://gitlab.onera.net/numerics/solver/sonics>`_ 
and `Fast <https://onera.github.io/Fast/>`_.
      
Current documentation is for version |version|. 
You may take note of what has changed compared with previous versions in the :doc:`changelog` section.

Please note the `GitLab page <https://gitlab.onera.net/numerics/mola>`_ of MOLA
and its associated `Issues <https://gitlab.onera.net/numerics/mola/-/issues>`_ section where
you can make suggestions or report bugs.

MOLA is distributed under licence `LGPLv3 <https://www.gnu.org/licenses/lgpl-3.0.en.html>`_.


.. toctree::
   :maxdepth: 1
   :caption: Contents:
   :hidden:

   user_manual/index
   examples/index
   tutorials/index
   developer_manual/index
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. rubric:: Footnotes

.. [#f1] Registered code ``IDDN.FR.001.240036.000.S.X.2022.000.31235``